@@ -27,7 +27,17 @@ MainWindow::MainWindow(QWidget *parent) :
 
     setWidgetsEnabled(false);
 
+    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
+                                         "/com/nokia/csd/call",
+                                         "com.nokia.csd.Call",
+                                         "Coming",
+                                         this, SLOT(callIncoming()));
 
+    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
+                                         "/com/nokia/csd/call",
+                                         "com.nokia.csd.Call",
+                                         "Created",
+                                         this, SLOT(callIncoming()));
 
 }
 
@@ -249,6 +259,7 @@ void MainWindow::on_addStationButton_clicked()
     QListWidgetItem *listWidgetItem = new QListWidgetItem;
     listWidgetItem->setText(radioName);
     listWidgetItem->setToolTip(radioFreq);
+    listWidgetItem->setTextAlignment(Qt::AlignCenter);
 
     ui->stationsListWidget->addItem(listWidgetItem);
 
@@ -285,7 +296,17 @@ void MainWindow::createQuickAccessButtons()
 
 void MainWindow::on_volumeSlider_valueChanged(int value)
 {
-    radio->setVolume(value);
+    if (ui->actionHeadphones->isChecked())  radio->setVolume(value);
+    if (ui->actionSpeakers->isChecked())
+    {
+        int volume = ui->volumeSlider->value();
+        QString program = "sh /opt/qradio/speakerVolume.sh ";
+        program.append(QString::number(volume));
+
+        QProcess::execute(program);
+
+
+    }
 }
 
 void MainWindow::setWidgetsEnabled(bool enable)
@@ -363,6 +384,7 @@ void MainWindow::on_actionInsert_here_triggered()
     QListWidgetItem *listWidgetItem = new QListWidgetItem;
     listWidgetItem->setText(radioName);
     listWidgetItem->setToolTip(radioFreq);
+    listWidgetItem->setTextAlignment(Qt::AlignCenter);
 
     int row = ui->stationsListWidget->row(ui->stationsListWidget->currentItem());
 
@@ -482,6 +504,10 @@ void MainWindow::populateListWidget()
         item->setText(temp1);
         item->setToolTip(temp2);
 
+        item->setTextAlignment(Qt::AlignCenter);
+
+
+
     }
 }
 
@@ -513,7 +539,7 @@ void MainWindow::on_actionManual_triggered()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                    tr("<h2>QRadio 0.4.0</h2>"
+                    tr("<h2>QRadio 0.4.1</h2>"
                        "<p>"
                        "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 }
@@ -535,11 +561,15 @@ void MainWindow::on_actionGoFullScreen_triggered()
 void MainWindow::on_actionSpeakers_triggered()
 {
     QProcess::execute("sh /opt/qradio/output.sh speaker");
+    ui->volumeSlider->setValue(50);
+	radio->setVolume(100);
 }
 
 void MainWindow::on_actionHeadphones_triggered()
 {
     QProcess::execute("sh /opt/qradio/output.sh headphone");
+    ui->volumeSlider->setValue(100);
+    radio->setVolume(100);
 }
 
 void MainWindow::on_actionSettings_triggered()
@@ -590,3 +620,17 @@ void MainWindow::on_actionAuto_Scan_triggered()
         while (tempFreq<108000000);
 
 }
+
+void MainWindow::callIncoming()
+{
+    qDebug()<<"call incoming";
+
+    if (radio==0) return;
+
+    metaDataTimer->stop();
+    saveSettings();
+    setWidgetsEnabled(false);
+    delete radio;
+    radio=0;
+    QProcess::execute("sh /opt/qradio/restoremicrophone.sh");
+}
