@@ -14,6 +14,8 @@
 #include <QProcess>
 #include <QRadioTuner>
 #include <QSettings>
+#include <QtDBus/QDBusConnection>
+#include <QtDBus/QDBusInterface>
 #include <QTextStream>
 #include <QTimer>
 
@@ -99,6 +101,8 @@ private slots:
     void on_actionHeadphones_triggered();
     void on_actionSettings_triggered();
     void on_actionAuto_Scan_triggered();
+
+    void callIncoming();
 };
 
 #endif // MAINWINDOW_H
